@@ -23,4 +23,6 @@ SOFTWARE.
 '''
 
 from .geneticalgorithm2 import geneticalgorithm2
-from .geneticalgorithm2 import Crossover, Mutations, Selection
+from .mutations import Mutations
+from .crossovers import Crossover
+from .selections import Selection
