@@ -322,7 +322,7 @@ class geneticalgorithm2():
 
 
         ############################################################# 
-    def run(self, no_plot = False, disable_progress_bar = False, set_function = None, apply_function_to_parents = False, start_generation = {'variables':None, 'scores': None}):
+    def run(self, no_plot = False, disable_progress_bar = False, set_function = None, apply_function_to_parents = False, start_generation = {'variables':None, 'scores': None}, studEA = False):
         """
         @param no_plot <boolean> - do not plot results using matplotlib by default
         
@@ -335,10 +335,14 @@ class geneticalgorithm2():
                                                                                                          
         @param start_generation <dictionary> - a dictionary with structure {'variables':2D-array of samples, 'scores': function values on samples}                                                                                                
         if 'scores' value is None the scores will be compute
+
+        @param studEA <boolean> - using stud EA strategy (crossover with best object always)
         """
         
-        show_progress = (lambda t, t2, s: self.progress(t, t2, status = s)) if  not disable_progress_bar else (lambda t, t2, s: None)
-                
+        show_progress = (lambda t, t2, s: self.progress(t, t2, status = s)) if not disable_progress_bar else (lambda t, t2, s: None)
+        
+        get_parents_inds = (lambda par_count: (0, random.randrange(1, par_count))) if studEA else (lambda par_count: tuple(np.random.randint(0, par_count, 2)))
+            
         ############################################################# 
         # Initial Population
         
@@ -434,8 +438,7 @@ class geneticalgorithm2():
             par = np.empty((self.par_s, self.dim+1))
             
             # elit parents
-            for k in range(0, self.num_elit):
-                par[k]=pop[k].copy()
+            par[:self.num_elit, :] = pop[:self.num_elit, :].copy()
                 
             # non-elit parents indexes
             #new_par_inds = np.int8(ff(pop[self.num_elit:, self.dim], self.par_s - self.num_elit) + self.num_elit)
@@ -455,12 +458,10 @@ class geneticalgorithm2():
             #New generation
             pop = np.empty((self.pop_s, self.dim+1))  #np.array([np.zeros(self.dim+1)]*self.pop_s)
             
-            for k in range(0 ,self.par_s):
-                pop[k] = par[k].copy()
+            pop[:self.par_s, :] = par[:self.par_s, :].copy()
                 
             for k in range(self.par_s, self.pop_s, 2):
-                r1 = np.random.randint(0, par_count)
-                r2 = np.random.randint(0, par_count)
+                r1, r2 = get_parents_inds(par_count)
                 pvar1 = ef_par[r1,:self.dim].copy()
                 pvar2 = ef_par[r2,:self.dim].copy()
                 
